/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

plugins {
    alias(libs.plugins.kotlinMultiplatform)
    alias(libs.plugins.kotlinxSerialization)
    id("convention.composeComp")
    id("convention.jetbrainsCmp")

    id("convention.formattingCmp")
}

kotlin {
    jvmToolchain(libs.versions.java.get().toInt())
    jvm("desktop")
    applyDefaultHierarchyTemplate()

    sourceSets {
        val commonMain by getting {
            dependencies {
                implementation(compose.ui)
                implementation(compose.runtime)
                implementation(compose.foundation)
                implementation(compose.material3)
                implementation(compose.materialIconsExtended)
                implementation(compose.components.resources)

                implementation(libs.koin.compose)
                implementation(libs.koin.composeVm)

                implementation(libs.jetbrains.lifecycle.viewmodel)
                implementation(libs.jetbrains.lifecycle.compose)
                implementation(libs.jetbrains.navigation.compose)

                implementation(project(":shared:shared"))

                implementation(libs.kmpWindowSizeClass)

                implementation(libs.composeTheme)
                implementation(libs.composeTheme.material3)
                implementation(libs.bundles.voyager)
                implementation(libs.alertKmp)
                implementation(libs.composables.core)

                implementation(libs.dotenv.vault)
            }
        }
        val commonTest by getting {
            dependencies {
                @OptIn(org.jetbrains.compose.ExperimentalComposeLibrary::class)
                implementation(compose.uiTest)
            }
        }
        val desktopMain by getting {
            dependencies {
                implementation(compose.desktop.common)
            }
        }
        val desktopTest by getting {
            dependencies {
                implementation(compose.desktop.currentOs)
            }
        }
    }
}

val appVersion = "1.0.0"
version = appVersion
