/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui

import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import com.composables.composetheme.ComposeTheme
import com.composables.composetheme.material3.colorScheme
import edu.ucsc.its.temerity.shared.data.repository.PlatformRepository
import edu.ucsc.its.temerity.shared.di.initKoin
import edu.ucsc.its.temerity.shared.ui.theme.DarkTheme
import edu.ucsc.its.temerity.shared.ui.theme.LightTheme
import edu.ucsc.its.temerity.shared.viewmodel.AppViewModel
import edu.ucsc.its.temerity.shared.viewmodel.RootViewModel
import org.koin.compose.koinInject
import org.koin.compose.viewmodel.koinViewModel
import org.koin.core.annotation.KoinExperimentalAPI

private val koin = initKoin().koin

@Composable
internal fun TemerityApp(
  appStateViewModel: AppViewModel = koinViewModel(),
  rootViewModel: RootViewModel = koinViewModel(),
  platformRepository: PlatformRepository = koinInject(),
) {
  val appTheme = if (isSystemInDarkTheme()) DarkTheme else LightTheme

  appTheme {
    Surface(
      modifier = Modifier.fillMaxSize(),
      color = ComposeTheme.colorScheme.surface,
    ) {
      Box(modifier = Modifier.fillMaxSize()) {
        RootScreen()
      }
    }
  }
}
