/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui.elements

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.drawWithContent
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.Layout

// Based on code snippet available at: https://gist.github.com/SEAbdulbasit/5cfe055294e13cbb18bb202369f1a8d6

@Composable
fun Gradient(modifier: Modifier = Modifier) {
  Layout(
    content = {
      Box(
        modifier = Modifier.fillMaxSize().drawWithContent {
          drawRect(
            Brush.radialGradient(
              colors = listOf(
                Color(0xff3e91f0),
                Color.Transparent,
              ),
              center = Offset(this.size.width * 0.05f, this.size.height / 2),
              radius = size.width * 2,
            ),
          )
        },
      )
      Box(
        modifier = Modifier.fillMaxSize().drawWithContent {
          drawRect(
            Brush.radialGradient(
              colors = listOf(
                Color(0xffFF8A58),
                Color.Transparent,
              ),
              center = Offset(0f, this.size.height),
              radius = size.height,
            ),
          )
        },
      )
      Box(
        modifier = Modifier.fillMaxSize().drawWithContent {
          drawRect(
            Brush.radialGradient(
              colors = listOf(
                Color(0xff58EBFF),
                Color.Transparent,
              ),
              center = Offset(
                this.size.width * 1.1f,
                this.size.height * .100f,
              ),
              radius = size.height,
            ),
          )
        },
      )
      Box(
        modifier = Modifier.fillMaxSize().drawWithContent {
          drawRect(
            Brush.radialGradient(
              colors = listOf(
                Color(0xff8c54eb),
                Color.Transparent,
              ),
              center = Offset(
                this.size.width,
                this.size.height * 0.9f,
              ),
              radius = size.height,
            ),
          )
        },
      )
    },
    measurePolicy = { measurables, constraints ->
      val placeables = measurables.map { it.measure(constraints) }
      layout(constraints.maxWidth, constraints.maxHeight) {
        placeables.forEach { it.place(0, 0) }
      }
    },
    modifier = modifier,
  )
}
