/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.viewmodel

import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import edu.ucsc.its.temerity.core.Temerity
import edu.ucsc.its.temerity.model.Device
import kotlinx.coroutines.flow.Flow
import org.koin.compose.getKoin

sealed interface DevicesScreenEvent

data class DevicesScreenState(
  val loading: Boolean,
  val devices: List<Device>,
)

class DevicesScreenViewModel : MoleculeViewModel<DevicesScreenEvent, DevicesScreenState>() {

  @Composable
  override fun models(events: Flow<DevicesScreenEvent>): DevicesScreenState {
    return devicesScreenPresenter(events, getKoin().get())
  }
}

@Composable
fun devicesScreenPresenter(events: Flow<DevicesScreenEvent>, client: Temerity): DevicesScreenState {
  var devices: List<Device> by remember { mutableStateOf(emptyList()) }

  LaunchedEffect(Unit) {
    devices = client.getDevices()
  }

  LaunchedEffect(Unit) {
    events.collect { event ->
    }
  }

  return DevicesScreenState(
    loading = false,
    devices = devices,
  )
}
