/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.viewmodel

import androidx.compose.runtime.Composable
import edu.ucsc.its.temerity.core.Temerity
import kotlinx.coroutines.flow.Flow
import org.koin.core.component.KoinComponent
import org.koin.core.component.get

sealed class RootEvent {
  data object NavigateToDevicesPane : RootEvent()
}

data class RootState(
  val loading: Boolean = false,
)

class RootViewModel :
  MoleculeViewModel<RootEvent, RootState>(),
  KoinComponent {

  @Composable
  override fun models(events: Flow<RootEvent>): RootState {
    return rootPresenter(events, get<Temerity>())
  }

  private fun rootPresenter(events: Flow<RootEvent>, client: Temerity): RootState {
    return RootState(false)
  }
}
