/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity

import edu.ucsc.its.temerity.core.TemDsl
import io.ktor.client.HttpClient
import io.ktor.client.HttpClientConfig
import io.ktor.client.plugins.logging.LoggingConfig

/**
 * Configuration for the Temerity client.
 * Adapted from the tmdb-api project: https://github.com/MoviebaseApp/tmdb-kotlin/raw/refs/heads/main/tmdb-api/src/commonMain/kotlin/app/moviebase/tmdb/TmdbClientConfig.kt
 */
@TemDsl
public class TemClientConfig {
  
  /**
   * Specifies URL of platform instance to make API calls to
   */
  public var serviceUrl: String? = null
  /**
   * Specifies the authorization token to use for API calls
   */
  public var serviceToken: String? = null
  /**
   * Specifies whether debug logging should be enabled
   * Enable this for debugging purposes only
   */
  public var optDebugEnabled: Boolean = false

  public var expectSuccess: Boolean = true
  public var useTimeout: Boolean = false
  public var maxRetriesOnException: Int? = null

  /**
   * Configures the HttpClient with the provided block.
   * @param () -> HttpClient The block to configure the HttpClient.
   */
  internal var httpClientConfigBlock: (HttpClientConfig<*>.() -> Unit)? = null
  internal var httpClientBuilder: (() -> HttpClient)? = null
  internal var httpClientLoggingBlock: (LoggingConfig.() -> Unit)? = null

  public fun logging(block: LoggingConfig.() -> Unit) {
    httpClientLoggingBlock = block
  }

  public fun httpClient(block: () -> HttpClient) {
    httpClientBuilder = block
  }

  public companion object {

    internal fun withToken(serviceToken: String): TemClientConfig = TemClientConfig().apply {
      this.serviceToken = serviceToken
    }
  }
}
