/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity.model

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

@Serializable
public data class DeviceRecordingSession(
  @SerialName("session_name")
  val sessionName: String = "",

  val isLiveStream: Boolean = false,

  @SerialName("start_timestamp")
  val startTimestamp: Long = -1,

  @SerialName("session_creator")
  val sessionCreator: String = "",

  @SerialName("owner_id")
  val ownerId: Long = -1,

  @SerialName("device_profile")
  val deviceProfile: String = "",

  @SerialName("session_id")
  val sessionId: Long = -1,

  val duration: String,

  @SerialName("start_time")
  val startTime: String = "",

  @SerialName("session_description")
  val sessionDescription: String = "",

  @SerialName("repeat_summary")
  val repeatSummary: String = "",

  @SerialName("class_name")
  val className: String = "",

  @SerialName("class_code")
  val classCode: String = "",

  @SerialName("platform_unique_id")
  val platformUniqueId: String = "",

  @SerialName("video_id")
  val videoId: Long = -1,
)

@Serializable
public data class Device(
  @SerialName("station_name")
  val stationName: String = "",

  @SerialName("access_level")
  val accessLevel: String = "",

  @SerialName("device_id")
  val deviceId: Long = -1,

  @SerialName("access_id")
  val accessId: String = "",

  @SerialName("station_type")
  val stationType: String = "",
)

internal data class DeviceRegistration(
  val name: String = "",

  @SerialName("device_type")
  val deviceType: String = "",

  @SerialName("access_level")
  val accessLevel: String = "",

  @SerialName("device_id")
  val deviceId: Long = -1,

  @SerialName("register_user_id")
  val registerUserId: String = "",
)

@Serializable
public data class UserRecordingSession(
  val duration: String = "",

  @SerialName("session_name")
  val sessionName: String = "",

  @SerialName("start_time")
  val startTime: String = "",

  @SerialName("start_timestamp")
  val startTimestamp: Long = -1,

  @SerialName("session_description")
  val sessionDescription: String = "",

  @SerialName("session_creator")
  val sessionCreator: String = "",

  @SerialName("repeat_summary")
  val repeatSummary: String = "",

  @SerialName("device_profile")
  val deviceProfile: String = "",

  @SerialName("session_id")
  val sessionId: Long = -1,

  @SerialName("class_name")
  val className: String = "",

  @SerialName("class_code")
  val classCode: String = "",

  @SerialName("video_id")
  val videoId: Long = -1,
)
